==============
 Introduction
==============

DIPY_ is always seeking courageous scientists who want to take dMRI
analysis to the next level. If you share the same vision and you are willing to share your code please let us know we will be happy to help.

The lead developer is Eleftherios Garyfallidis, with support from Ian
Nimmo-Smith, Matthew Brett, Bago Amirbekian, Ariel Rokem, Stefan van der Walt and (your name here). See the main documentation for the full list of DIPY developers and contributors.

The primary development repository is `dipy github`_

Please do contribute.  Have a look at :ref:`using-git` for some ideas on
how to get going.

Have a look at the `nipy development guidelines`_ for our coding habits.
In summary, please follow the `numpy coding style`_ - and of course -
PEP8_ .  Test everything!  We are using pytest_ ; see the existing code
for example tests.  If you can please use our :ref:`commit-codes`.

But - just pitch in - send us some code - we'll give you feedback if you
want it - that way we learn from each other.

And - welcome...

If you are new to diffusion MRI and you want to learn more here is a simple `video <http://www.youtube.com/watch?v=tNB0sM7JJqg>`_  we
made for the general public. I hope you enjoy it and apologies for the low resolution.


.. include:: ../links_names.inc
